@@ -1,5 +1,5 @@
 """URLs for the aps_purchasing app."""
-from django.conf.urls import patterns, url
+from django.conf.urls import patterns
 
 
 urlpatterns = patterns(
